<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clique no ícone da área de notificação 
ou pressione novamente o atalho para parar de gravar</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Não rodar o seu ecrã durante a gravação</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravação</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar para a área de transferência (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Falha ao guardar. Guarde-a no diretório pessoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de ecrã concluída</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>selecione a área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de transferência</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>A guardar o ficheiro da gravação do ecrã, aguarde...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Como os efeitos visuais são desativados durante o processo, a gravação tem de ser interrompida</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Afixar capturas de ecrã</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Captura concluída e copiada para a área de transferência</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Definir um caminho para salvar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Alterar o caminho para salvar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Afixar capturas de ecrã</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravando</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado em %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir pasta</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecionar uma localização ao guardar</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Atualizar a localização ao guardar</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de ecrã irá começar em %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obter ajuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Falha ao tirar uma captura de ecrã contínua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Atingiu o fundo da área de rolagem</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Atingiu o comprimento máximo</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar a área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Deslize a roda rato ou clique para tirar um screenshot com função deslizar </translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Diminuir a velocidade de deslizar</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Área inválida, clique para</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aqui</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Captura de ecrã</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Sair/Guardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste do tamanho</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Início rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capturar janela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atraso na captura de ecrã</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de ecrã inteiro</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar a altura</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura para baixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar largura à esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar largura à direita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuir altura para baixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuir largura à esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuir largura à direita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar a gravação</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Gravação</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Afixar capturas de ecrã</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Iniciar OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Iniciar scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectângulo
Pressionar e manter Shift para desenhar um quadrado</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipse
Pressionar e manter Shift para desenhar um círculo</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pincel
Pressionar e manter Shift para desenhar uma linha reta</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Ajustar a intensidade do desfoque (Scroll para ajustar)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Ajustar o tamanho do pincel (Scroll para ajustar)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Ajustar o tamanho do texto (Scroll para ajustar)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Mostrar pressão da tecla (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Ocultar pressão da tecla (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Mostrar pressão da tecla (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Ligar câmara (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Desligar câmara (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Definições (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfone</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Áudio do sistema</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar cursor</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Mostrar clique</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Guardar em</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Ambiente de trabalho</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linha (L)
Pressionar e manter Shift para desenhar uma linha vertical ou horizontal</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Seta (X)
Pressionar e manter Shift para desenhar uma seta vertical ou horizontal</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Lápis (L)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Desfocar (D)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Texto (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extrair texto (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Afixar capturas de ecrã (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Anular (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Alterar o caminho para salvar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efeitos de contorno</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Sombra</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Contorno</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Ferramentas geométricas (R)
Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Salvar localmente</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Salvar em %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Atualizar a localização ao guardar</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecionar uma localização ao guardar</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar para a área de transferência (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajustar a área de gravação dentro de %1*%2 para obter um melhor efeito de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>A gravação do ecrã não é atualmente suportada</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>
